@@ -10,10 +10,13 @@ from __future__ import absolute_import
 
 from . import define_allomorph_picker
 from .morpheme import Morpheme
-from .substantive import Noun, NumberWord
+from .substantive import Noun, NumberWord, Loanword
 from .. import hangul
 
 
+__all__ = ['Particle']
+
+
 class Particle(Morpheme):
     """Particle (조사) is a postposition in Korean. Some particles are
     allomorph such as 을/를, 이/가. These forms follow forward syllable ends
@@ -93,5 +96,6 @@ class Particle(Morpheme):
 
     @define_allomorph_picker(suffix_of=Noun)
     @define_allomorph_picker(suffix_of=NumberWord)
+    @define_allomorph_picker(suffix_of=Loanword)
     def pick_allomorph_after_substantive(self, substantive):
         return self.pick_allomorph_after_char(substantive.read()[-1])
